@@ -1,5 +1,3 @@
-# coding: utf-8
-
 """
 This module defines tasks for writing FEFF input sets.
 """
@@ -10,8 +8,8 @@ from fireworks import FiretaskBase, explicit_serialize
 
 from atomate.utils.utils import load_class
 
-__author__ = 'Kiran Mathew'
-__email__ = 'kmathew@lbl.gov'
+__author__ = "Kiran Mathew"
+__email__ = "kmathew@lbl.gov"
 
 
 @explicit_serialize
@@ -30,13 +28,18 @@ class WriteFeffFromIOSet(FiretaskBase):
         radius (float): cluster radius in angstroms
         other_params (dict): **kwargs to pass into the desired InputSet if using str feff_input_set
     """
+
     required_params = ["absorbing_atom", "structure", "feff_input_set"]
     optional_params = ["radius", "other_params"]
 
     def run_task(self, fw_spec):
-        feff_input_set = get_feff_input_set_obj(self["feff_input_set"], self["absorbing_atom"],
-                                                self["structure"], self.get("radius", 10.0),
-                                                **self.get("other_params", {}))
+        feff_input_set = get_feff_input_set_obj(
+            self["feff_input_set"],
+            self["absorbing_atom"],
+            self["structure"],
+            self.get("radius", 10.0),
+            **self.get("other_params", {}),
+        )
         feff_input_set.write_input(".")
 
 
@@ -52,11 +55,12 @@ class WriteEXAFSPaths(FiretaskBase):
     Optional_params:
         degeneracies (list): list of path degeneracies.
     """
+
     required_params = ["feff_input_set", "paths"]
     optional_params = ["degeneracies"]
 
     def run_task(self, fw_spec):
-        atoms = self['feff_input_set'].atoms
+        atoms = self["feff_input_set"].atoms
         paths = Paths(atoms, self["paths"], degeneracies=self.get("degeneracies", []))
         paths.write_file()
 
@@ -77,9 +81,9 @@ def get_feff_input_set_obj(fis, *args, **kwargs):
     """
     # e.g. "pymatgen.io.feff.sets.MPXANESSet" or "XANES"
     if isinstance(fis, str):
-        fis_ = "pymatgen.io.feff.sets.MP{}Set".format(fis) if "pymatgen" not in fis else fis
+        fis_ = f"pymatgen.io.feff.sets.MP{fis}Set" if "pymatgen" not in fis else fis
         modname, classname = fis_.strip().rsplit(".", 1)
         fis_cls = load_class(modname, classname)
         return fis_cls(*args, **kwargs)
     else:
-        return fis
\ No newline at end of file
+        return fis
