@@ -1,6 +1,3 @@
-# coding: utf-8
-
-
 """
 This module defines FEFF XAS(XANES/EXAFS) workflows.
 """
@@ -15,15 +12,24 @@ from atomate.utils.utils import get_logger
 from atomate.feff.fireworks.core import XASFW, EXAFSPathsFW, EELSFW
 from atomate.feff.firetasks.write_inputs import get_feff_input_set_obj
 
-__author__ = 'Kiran Mathew'
-__email__ = 'kmathew@lbl.gov'
+__author__ = "Kiran Mathew"
+__email__ = "kmathew@lbl.gov"
 
 logger = get_logger(__name__)
 
 
-def get_wf_xas(absorbing_atom, structure, feff_input_set="pymatgen.io.feff.sets.MPXANESSet",
-               edge="K", radius=10.0, feff_cmd="feff", db_file=None, metadata=None,
-               user_tag_settings=None, use_primitive=False):
+def get_wf_xas(
+    absorbing_atom,
+    structure,
+    feff_input_set="pymatgen.io.feff.sets.MPXANESSet",
+    edge="K",
+    radius=10.0,
+    feff_cmd="feff",
+    db_file=None,
+    metadata=None,
+    user_tag_settings=None,
+    use_primitive=False,
+):
     """
     Returns FEFF XANES/EXAFS spectroscopy workflow.
 
@@ -56,31 +62,56 @@ def get_wf_xas(absorbing_atom, structure, feff_input_set="pymatgen.io.feff.sets.
 
     override_default_feff_params = {"user_tag_settings": user_tag_settings}
 
-    spectrum_type = get_feff_input_set_obj(feff_input_set, ab_atom_indices[0], structure).__class__.__name__[2:-3]
+    spectrum_type = get_feff_input_set_obj(
+        feff_input_set, ab_atom_indices[0], structure
+    ).__class__.__name__[2:-3]
 
     # add firework for each absorbing atom site index
     fws = []
     for ab_idx in ab_atom_indices:
         fw_metadata = dict(metadata) if metadata else {}
         fw_metadata["absorbing_atom_index"] = ab_idx
-        fw_name = "{}-{}-{}".format(spectrum_type, edge, ab_idx)
-        fws.append(XASFW(ab_idx, structure, edge=edge, radius=radius,
-                         feff_input_set=feff_input_set, feff_cmd=feff_cmd, db_file=db_file,
-                         metadata=fw_metadata, name=fw_name,
-                         override_default_feff_params=override_default_feff_params))
+        fw_name = f"{spectrum_type}-{edge}-{ab_idx}"
+        fws.append(
+            XASFW(
+                ab_idx,
+                structure,
+                edge=edge,
+                radius=radius,
+                feff_input_set=feff_input_set,
+                feff_cmd=feff_cmd,
+                db_file=db_file,
+                metadata=fw_metadata,
+                name=fw_name,
+                override_default_feff_params=override_default_feff_params,
+            )
+        )
 
     wf_metadata = dict(metadata) if metadata else {}
     wf_metadata["absorbing_atom_indices"] = list(ab_atom_indices)
-    wfname = "{}:{}:{} edge".format(structure.composition.reduced_formula,
-                                    "{} spectroscopy".format(spectrum_type), edge)
+    wfname = "{}:{}:{} edge".format(
+        structure.composition.reduced_formula, f"{spectrum_type} spectroscopy", edge
+    )
 
     return Workflow(fws, name=wfname, metadata=wf_metadata)
 
 
-def get_wf_exafs_paths(absorbing_atom, structure, paths, degeneracies=None, edge="K", radius=10.0,
-                       feff_input_set="pymatgen.io.feff.sets.MPEXAFSSet", feff_cmd="feff",
-                       db_file=None, metadata=None, user_tag_settings=None, use_primitive=False,
-                       labels=None, filepad_file=None):
+def get_wf_exafs_paths(
+    absorbing_atom,
+    structure,
+    paths,
+    degeneracies=None,
+    edge="K",
+    radius=10.0,
+    feff_input_set="pymatgen.io.feff.sets.MPEXAFSSet",
+    feff_cmd="feff",
+    db_file=None,
+    metadata=None,
+    user_tag_settings=None,
+    use_primitive=False,
+    labels=None,
+    filepad_file=None,
+):
     """
     Returns FEFF EXAFS spectroscopy workflow that generates the scattering amplitudes for the given
     list of scattering paths. The scattering amplitude output files(feffNNNN.dat files) are
@@ -113,21 +144,54 @@ def get_wf_exafs_paths(absorbing_atom, structure, paths, degeneracies=None, edge
         Workflow
     """
     labels = labels or []
-    wflow = get_wf_xas(absorbing_atom, structure, feff_input_set, edge, radius, feff_cmd,
-                       db_file, metadata, user_tag_settings, use_primitive)
-    paths_fw = EXAFSPathsFW(absorbing_atom, structure, paths, degeneracies=degeneracies, edge=edge,
-                            radius=radius, name="EXAFS Paths", feff_input_set=feff_input_set,
-                            feff_cmd=feff_cmd, labels=labels, filepad_file=filepad_file)
+    wflow = get_wf_xas(
+        absorbing_atom,
+        structure,
+        feff_input_set,
+        edge,
+        radius,
+        feff_cmd,
+        db_file,
+        metadata,
+        user_tag_settings,
+        use_primitive,
+    )
+    paths_fw = EXAFSPathsFW(
+        absorbing_atom,
+        structure,
+        paths,
+        degeneracies=degeneracies,
+        edge=edge,
+        radius=radius,
+        name="EXAFS Paths",
+        feff_input_set=feff_input_set,
+        feff_cmd=feff_cmd,
+        labels=labels,
+        filepad_file=filepad_file,
+    )
     # append the scattering paths firework to the regular EXAFS workflow.
     paths_wf = Workflow.from_Firework(paths_fw)
     wflow.append_wf(paths_wf, wflow.leaf_fw_ids)
     return wflow
 
 
-def get_wf_eels(absorbing_atom, structure=None, feff_input_set="pymatgen.io.feff.sets.MPELNESSet",
-                edge="K", radius=10., beam_energy=100, beam_direction=None, collection_angle=1,
-                convergence_angle=1, user_eels_settings=None, user_tag_settings=None, feff_cmd="feff",
-                db_file=None, metadata=None, use_primitive=False):
+def get_wf_eels(
+    absorbing_atom,
+    structure=None,
+    feff_input_set="pymatgen.io.feff.sets.MPELNESSet",
+    edge="K",
+    radius=10.0,
+    beam_energy=100,
+    beam_direction=None,
+    collection_angle=1,
+    convergence_angle=1,
+    user_eels_settings=None,
+    user_tag_settings=None,
+    feff_cmd="feff",
+    db_file=None,
+    metadata=None,
+    use_primitive=False,
+):
     """
     Returns FEFF ELNES/EXELFS spectroscopy workflow.
 
@@ -165,23 +229,39 @@ def get_wf_eels(absorbing_atom, structure=None, feff_input_set="pymatgen.io.feff
 
     override_default_feff_params = {"user_tag_settings": user_tag_settings}
 
-    spectrum_type = get_feff_input_set_obj(feff_input_set, ab_atom_indices[0], structure).__class__.__name__[2:-3]
+    spectrum_type = get_feff_input_set_obj(
+        feff_input_set, ab_atom_indices[0], structure
+    ).__class__.__name__[2:-3]
 
     # add firework for each absorbing atom site index
     fws = []
     for ab_idx in ab_atom_indices:
         fw_metadata = dict(metadata) if metadata else {}
         fw_metadata["absorbing_atom_index"] = ab_idx
-        fw_name = "{}-{}-{}".format(spectrum_type, edge, ab_idx)
-        fws.append(EELSFW(ab_idx, structure, feff_input_set=feff_input_set, edge=edge, radius=radius,
-                          beam_energy=beam_energy, beam_direction=beam_direction,
-                          collection_angle=collection_angle, convergence_angle=convergence_angle,
-                          user_eels_settings=user_eels_settings, feff_cmd=feff_cmd, db_file=db_file,
-                          metadata=fw_metadata, name=fw_name,
-                          override_default_feff_params=override_default_feff_params))
+        fw_name = f"{spectrum_type}-{edge}-{ab_idx}"
+        fws.append(
+            EELSFW(
+                ab_idx,
+                structure,
+                feff_input_set=feff_input_set,
+                edge=edge,
+                radius=radius,
+                beam_energy=beam_energy,
+                beam_direction=beam_direction,
+                collection_angle=collection_angle,
+                convergence_angle=convergence_angle,
+                user_eels_settings=user_eels_settings,
+                feff_cmd=feff_cmd,
+                db_file=db_file,
+                metadata=fw_metadata,
+                name=fw_name,
+                override_default_feff_params=override_default_feff_params,
+            )
+        )
 
-    wfname = "{}:{}:{} edge".format(structure.composition.reduced_formula,
-                                    "{} spectroscopy".format(spectrum_type), edge)
+    wfname = "{}:{}:{} edge".format(
+        structure.composition.reduced_formula, f"{spectrum_type} spectroscopy", edge
+    )
     wf_metadata = dict(metadata) if metadata else {}
     wf_metadata["absorbing_atom_indices"] = list(ab_atom_indices)
 
