@@ -1,12 +1,9 @@
-# coding: utf-8
-
-
 from fireworks import explicit_serialize
 
 from atomate.common.firetasks.glue_tasks import get_calc_loc, CopyFiles
 
-__author__ = 'Kiran Mathew'
-__email__ = 'kmathew@lbl.gov'
+__author__ = "Kiran Mathew"
+__email__ = "kmathew@lbl.gov"
 
 
 @explicit_serialize
@@ -29,9 +26,17 @@ class CopyPackmolOutputs(CopyFiles):
 
     def run_task(self, fw_spec):
 
-        calc_loc = get_calc_loc(self["calc_loc"], fw_spec["calc_locs"]) if self.get("calc_loc") else {}
+        calc_loc = (
+            get_calc_loc(self["calc_loc"], fw_spec["calc_locs"])
+            if self.get("calc_loc")
+            else {}
+        )
         exclude_files = self.get("exclude_files", [])
 
-        self.setup_copy(self.get("calc_dir", None), filesystem=self.get("filesystem", None),
-                        exclude_files=exclude_files, from_path_dict=calc_loc)
+        self.setup_copy(
+            self.get("calc_dir", None),
+            filesystem=self.get("filesystem", None),
+            exclude_files=exclude_files,
+            from_path_dict=calc_loc,
+        )
         self.copy_files()
