@@ -1,6 +1,3 @@
-# coding: utf-8
-
-
 """
 Defines fireworks to be incorporated into workflows.
 """
@@ -12,17 +9,29 @@ from fireworks import Firework
 from atomate.common.firetasks.glue_tasks import PassCalcLocs
 from atomate.lammps.firetasks.run_calc import RunLammpsDirect, RunPackmol
 from atomate.lammps.firetasks.parse_outputs import LammpsToDB
-from atomate.lammps.firetasks.write_inputs import WriteInputFromIOSet, WriteInputFromForceFieldAndTopology
+from atomate.lammps.firetasks.write_inputs import (
+    WriteInputFromIOSet,
+    WriteInputFromForceFieldAndTopology,
+)
 
 __author__ = "Brandon Wood, Kiran Mathew"
 __email__ = "b.wood@berkeley.edu"
 
 
 class LammpsFW(Firework):
-
-    def __init__(self, lammps_input_set, input_filename="lammps.in", data_filename="lammps.data",
-                 lammps_cmd="lammps", db_file=None, parents=None, name="LammpsFW",
-                 log_filename="log.lammps", dump_filename=None, **kwargs):
+    def __init__(
+        self,
+        lammps_input_set,
+        input_filename="lammps.in",
+        data_filename="lammps.data",
+        lammps_cmd="lammps",
+        db_file=None,
+        parents=None,
+        name="LammpsFW",
+        log_filename="log.lammps",
+        dump_filename=None,
+        **kwargs
+    ):
         """
         write lammps inputset, run, and store the output.
 
@@ -41,26 +50,47 @@ class LammpsFW(Firework):
         """
 
         tasks = [
-            WriteInputFromIOSet(lammps_input_set=lammps_input_set, input_filename=input_filename,
-                                data_filename=data_filename),
-
+            WriteInputFromIOSet(
+                lammps_input_set=lammps_input_set,
+                input_filename=input_filename,
+                data_filename=data_filename,
+            ),
             RunLammpsDirect(lammps_cmd=lammps_cmd, input_filename=input_filename),
-
-            LammpsToDB(input_filename=input_filename, data_filename=data_filename,
-                       log_filename=log_filename, dump_filename=dump_filename,
-                       db_file=db_file, additional_fields={"task_label": name})
+            LammpsToDB(
+                input_filename=input_filename,
+                data_filename=data_filename,
+                log_filename=log_filename,
+                dump_filename=dump_filename,
+                db_file=db_file,
+                additional_fields={"task_label": name},
+            ),
         ]
 
-        super(LammpsFW, self).__init__(tasks, parents=parents, name=name, **kwargs)
+        super().__init__(tasks, parents=parents, name=name, **kwargs)
 
 
 class LammpsForceFieldFW(Firework):
-
-    def __init__(self, input_file, final_molecule, forcefield, box_size, topologies=None,
-                 constituent_molecules=None, mols_number=None, user_settings=None,
-                 ff_site_property=None, input_filename="lammps.in", data_filename="lammps.data",
-                 lammps_cmd="lammps", db_file=None, parents=None, log_filename="log.lammps",
-                 dump_filenames=None, name="LammpsFFFW", **kwargs):
+    def __init__(
+        self,
+        input_file,
+        final_molecule,
+        forcefield,
+        box_size,
+        topologies=None,
+        constituent_molecules=None,
+        mols_number=None,
+        user_settings=None,
+        ff_site_property=None,
+        input_filename="lammps.in",
+        data_filename="lammps.data",
+        lammps_cmd="lammps",
+        db_file=None,
+        parents=None,
+        log_filename="log.lammps",
+        dump_filenames=None,
+        name="LammpsFFFW",
+        **kwargs
+    ):
         """
         Write lammps input from forcefield and topology, run lammps, store results. Can be used
         with RunPackmol firework.
@@ -90,32 +120,53 @@ class LammpsForceFieldFW(Firework):
         user_settings = user_settings or {}
         constituent_molecules = constituent_molecules or [final_molecule]
         mols_number = mols_number or [1]
-        topologies = topologies or Topology.from_molecule(final_molecule, ff_map=ff_site_property)
+        topologies = topologies or Topology.from_molecule(
+            final_molecule, ff_map=ff_site_property
+        )
 
         tasks = [
-
-            WriteInputFromForceFieldAndTopology(input_file=input_file, final_molecule=final_molecule,
-                                                constituent_molecules=constituent_molecules,
-                                                mols_number=mols_number, forcefield=forcefield,
-                                                topologies=topologies, input_filename=input_filename,
-                                                user_settings=user_settings, data_filename=data_filename,
-                                                ff_site_property=ff_site_property, box_size=box_size),
-
+            WriteInputFromForceFieldAndTopology(
+                input_file=input_file,
+                final_molecule=final_molecule,
+                constituent_molecules=constituent_molecules,
+                mols_number=mols_number,
+                forcefield=forcefield,
+                topologies=topologies,
+                input_filename=input_filename,
+                user_settings=user_settings,
+                data_filename=data_filename,
+                ff_site_property=ff_site_property,
+                box_size=box_size,
+            ),
             RunLammpsDirect(lammps_cmd=lammps_cmd, input_filename=input_filename),
+            LammpsToDB(
+                input_filename=input_filename,
+                data_filename=data_filename,
+                log_filename=log_filename,
+                dump_filenames=dump_filenames,
+                db_file=db_file,
+                additional_fields={"task_label": name},
+            ),
+        ]
 
-            LammpsToDB(input_filename=input_filename, data_filename=data_filename,
-                       log_filename=log_filename, dump_filenames=dump_filenames,
-                       db_file=db_file, additional_fields={"task_label": name})
-            ]
-
-        super(LammpsForceFieldFW, self).__init__(tasks, parents=parents, name=name, **kwargs)
+        super().__init__(tasks, parents=parents, name=name, **kwargs)
 
 
 class PackmolFW(Firework):
-
-    def __init__(self, molecules, packing_config, tolerance=2.0, filetype="xyz", control_params=None,
-                 output_file="packed.xyz", site_property=None, parents=None, name="PackmolFW",
-                 packmol_cmd="packmol", **kwargs):
+    def __init__(
+        self,
+        molecules,
+        packing_config,
+        tolerance=2.0,
+        filetype="xyz",
+        control_params=None,
+        output_file="packed.xyz",
+        site_property=None,
+        parents=None,
+        name="PackmolFW",
+        packmol_cmd="packmol",
+        **kwargs
+    ):
         """
 
         Args:
@@ -134,15 +185,20 @@ class PackmolFW(Firework):
             packmol_cmd (str): path to packmol bin
             **kwargs:
         """
-        control_params = control_params or {'maxit': 20, 'nloop': 600}
+        control_params = control_params or {"maxit": 20, "nloop": 600}
 
         tasks = [
-            RunPackmol(molecules=molecules, packing_config=packing_config, tolerance=tolerance,
-                       filetype=filetype, control_params=control_params,  output_file=output_file,
-                       site_property=site_property, packmol_cmd=packmol_cmd),
+            RunPackmol(
+                molecules=molecules,
+                packing_config=packing_config,
+                tolerance=tolerance,
+                filetype=filetype,
+                control_params=control_params,
+                output_file=output_file,
+                site_property=site_property,
+                packmol_cmd=packmol_cmd,
+            ),
+            PassCalcLocs(name=name),
+        ]
 
-            PassCalcLocs(name=name)
-
-             ]
-
-        super(PackmolFW, self).__init__(tasks, parents=parents, name=name, **kwargs)
+        super().__init__(tasks, parents=parents, name=name, **kwargs)
