@@ -1,6 +1,3 @@
-# coding: utf-8
-
-
 """
 This module defines functions that yield lammps workflows
 """
@@ -12,13 +9,21 @@ from fireworks import Workflow
 
 from atomate.lammps.fireworks.core import LammpsFW, PackmolFW, LammpsForceFieldFW
 
-__author__ = 'Kiran Mathew'
+__author__ = "Kiran Mathew"
 __email__ = "kmathew@lbl.gov"
 
 
-def get_wf_basic(input_file, user_settings, lammps_data=None, input_filename="lammps.in",
-                 is_forcefield=False, lammps_cmd="lmp_serial", dump_filenames=None, db_file=None,
-                 name="LAMMPS Wflow"):
+def get_wf_basic(
+    input_file,
+    user_settings,
+    lammps_data=None,
+    input_filename="lammps.in",
+    is_forcefield=False,
+    lammps_cmd="lmp_serial",
+    dump_filenames=None,
+    db_file=None,
+    name="LAMMPS Wflow",
+):
     """
     Returns basic lammps workflow. This is more useful if the input_file is template file with
     the corresponding settings defined in user_settings
@@ -44,7 +49,9 @@ def get_wf_basic(input_file, user_settings, lammps_data=None, input_filename="la
     """
     wf_name = name
     user_settings = user_settings or {}
-    user_settings = user_settings if isinstance(user_settings, list) else [user_settings]
+    user_settings = (
+        user_settings if isinstance(user_settings, list) else [user_settings]
+    )
 
     fws = []
     for settings in user_settings:
@@ -55,23 +62,47 @@ def get_wf_basic(input_file, user_settings, lammps_data=None, input_filename="la
             settings["log_file"] = "log.lammps"
         log_filename = settings["log_file"]
 
-        lammps_input_set = LammpsInputSet.from_file(wf_name, input_file,
-                                                    user_settings=settings, lammps_data=lammps_data,
-                                                    data_filename=data_filename)
+        lammps_input_set = LammpsInputSet.from_file(
+            wf_name,
+            input_file,
+            user_settings=settings,
+            lammps_data=lammps_data,
+            data_filename=data_filename,
+        )
 
         fws.append(
-            LammpsFW(lammps_input_set=lammps_input_set, input_filename=input_filename,
-                     data_filename=data_filename, lammps_cmd=lammps_cmd, db_file=db_file,
-                     log_filename=log_filename, dump_filename=dump_filenames)
+            LammpsFW(
+                lammps_input_set=lammps_input_set,
+                input_filename=input_filename,
+                data_filename=data_filename,
+                lammps_cmd=lammps_cmd,
+                db_file=db_file,
+                log_filename=log_filename,
+                dump_filename=dump_filenames,
+            )
         )
 
     return Workflow(fws, name=name)
 
 
-def get_packmol_wf(input_file, user_settings, constituent_molecules, packing_config, forcefield,
-                   final_box_size, topologies=None, ff_site_property=None, tolerance=2.0, filetype="xyz",
-                   control_params=None, lammps_cmd="lmp_serial", packmol_cmd="packmol",
-                   dump_filenames=None, db_file=None, name="Packmol Lammps Wflow"):
+def get_packmol_wf(
+    input_file,
+    user_settings,
+    constituent_molecules,
+    packing_config,
+    forcefield,
+    final_box_size,
+    topologies=None,
+    ff_site_property=None,
+    tolerance=2.0,
+    filetype="xyz",
+    control_params=None,
+    lammps_cmd="lmp_serial",
+    packmol_cmd="packmol",
+    dump_filenames=None,
+    db_file=None,
+    name="Packmol Lammps Wflow",
+):
     """
     Returns workflow that uses Packmol to pack the constituent molecules into the given
     configuration and then run lammps on the final packed molecule for the given list of
@@ -101,23 +132,33 @@ def get_packmol_wf(input_file, user_settings, constituent_molecules, packing_con
         Workflow
     """
 
-    user_settings = user_settings if isinstance(user_settings, list) else [user_settings]
+    user_settings = (
+        user_settings if isinstance(user_settings, list) else [user_settings]
+    )
 
-    packmol_output_file = "packed_mol.{}".format(filetype)
+    packmol_output_file = f"packed_mol.{filetype}"
     mols_number = [mol_config["number"] for mol_config in packing_config]
 
     topologies = topologies or []
     # if not given then get the topology from the constituent molecules.
     if not topologies:
-        topologies = [Topology.from_molecule(mol, ff_map=ff_site_property or "ff_map")
-                      for mol in constituent_molecules]
+        topologies = [
+            Topology.from_molecule(mol, ff_map=ff_site_property or "ff_map")
+            for mol in constituent_molecules
+        ]
 
     fws = []
 
-    fw_packmol = PackmolFW(constituent_molecules, packing_config, tolerance=tolerance,
-                           filetype=filetype, control_params=control_params,
-                           output_file=packmol_output_file,
-                           site_property=ff_site_property, packmol_cmd=packmol_cmd)
+    fw_packmol = PackmolFW(
+        constituent_molecules,
+        packing_config,
+        tolerance=tolerance,
+        filetype=filetype,
+        control_params=control_params,
+        output_file=packmol_output_file,
+        site_property=ff_site_property,
+        packmol_cmd=packmol_cmd,
+    )
 
     fws.append(fw_packmol)
 
@@ -129,13 +170,24 @@ def get_packmol_wf(input_file, user_settings, constituent_molecules, packing_con
             setting["log_file"] = "log.lammps"
         log_filename = setting["log_file"]
 
-        fw_lammps = LammpsForceFieldFW(input_file, packmol_output_file, forcefield, final_box_size,
-                                       topologies=topologies, constituent_molecules=constituent_molecules,
-                                       mols_number=mols_number, user_settings=setting,
-                                       ff_site_property=ff_site_property, input_filename="lammps.in",
-                                       data_filename=data_filename, lammps_cmd=lammps_cmd,
-                                       db_file=db_file, log_filename=log_filename,
-                                       dump_filenames=dump_filenames, parents=[fw_packmol])
+        fw_lammps = LammpsForceFieldFW(
+            input_file,
+            packmol_output_file,
+            forcefield,
+            final_box_size,
+            topologies=topologies,
+            constituent_molecules=constituent_molecules,
+            mols_number=mols_number,
+            user_settings=setting,
+            ff_site_property=ff_site_property,
+            input_filename="lammps.in",
+            data_filename=data_filename,
+            lammps_cmd=lammps_cmd,
+            db_file=db_file,
+            log_filename=log_filename,
+            dump_filenames=dump_filenames,
+            parents=[fw_packmol],
+        )
         fws.append(fw_lammps)
 
     return Workflow(fws, name=name)
