@@ -1,6 +1,3 @@
-# coding: utf-8
-
-
 # This module defines firetasks for writing QChem input files
 
 from fireworks import FiretaskBase, explicit_serialize, FWAction
@@ -48,9 +45,13 @@ class RotateTorsion(FiretaskBase):
             )
 
         babe_mol = BabelMolAdaptor(start_mol).openbabel_mol
-        babe_mol.SetTorsion(self["atom_indexes"][0], self["atom_indexes"][1],
-                            self["atom_indexes"][2], self["atom_indexes"][3],
-                            (self["angle"] * np.pi / 180.))
+        babe_mol.SetTorsion(
+            self["atom_indexes"][0],
+            self["atom_indexes"][1],
+            self["atom_indexes"][2],
+            self["atom_indexes"][3],
+            (self["angle"] * np.pi / 180.0),
+        )
         rotated_mol = BabelMolAdaptor(babe_mol).pymatgen_mol
 
         # update the fw_spec with the rotated geometry
