@@ -1,5 +1,3 @@
-# coding: utf-8
-
 # Defines standardized Fireworks that can be chained easily to perform various
 # sequences of QChem calculations.
 
@@ -24,16 +22,18 @@ __credits__ = "Brandon Wood, Shyam Dwaraknath"
 
 
 class SinglePointFW(Firework):
-    def __init__(self,
-                 molecule=None,
-                 name="single point",
-                 qchem_cmd=">>qchem_cmd<<",
-                 multimode=">>multimode<<",
-                 max_cores=">>max_cores<<",
-                 qchem_input_params=None,
-                 db_file=None,
-                 parents=None,
-                 **kwargs):
+    def __init__(
+        self,
+        molecule=None,
+        name="single point",
+        qchem_cmd=">>qchem_cmd<<",
+        multimode=">>multimode<<",
+        max_cores=">>max_cores<<",
+        qchem_input_params=None,
+        db_file=None,
+        parents=None,
+        **kwargs
+    ):
         """
 
         Args:
@@ -66,15 +66,17 @@ class SinglePointFW(Firework):
         """
 
         qchem_input_params = qchem_input_params or {}
-        input_file="mol.qin"
-        output_file="mol.qout"
+        input_file = "mol.qin"
+        output_file = "mol.qout"
         t = []
         t.append(
             WriteInputFromIOSet(
                 molecule=molecule,
                 qchem_input_set="SinglePointSet",
                 input_file=input_file,
-                qchem_input_params=qchem_input_params))
+                qchem_input_params=qchem_input_params,
+            )
+        )
         t.append(
             RunQChemCustodian(
                 qchem_cmd=qchem_cmd,
@@ -82,31 +84,33 @@ class SinglePointFW(Firework):
                 input_file=input_file,
                 output_file=output_file,
                 max_cores=max_cores,
-                job_type="normal"))
+                job_type="normal",
+            )
+        )
         t.append(
             QChemToDb(
                 db_file=db_file,
                 input_file=input_file,
                 output_file=output_file,
-                additional_fields={"task_label": name}))
-        super(SinglePointFW, self).__init__(
-            t,
-            parents=parents,
-            name=name,
-            **kwargs)
+                additional_fields={"task_label": name},
+            )
+        )
+        super().__init__(t, parents=parents, name=name, **kwargs)
 
 
 class OptimizeFW(Firework):
-    def __init__(self,
-                 molecule=None,
-                 name="structure optimization",
-                 qchem_cmd=">>qchem_cmd<<",
-                 multimode=">>multimode<<",
-                 max_cores=">>max_cores<<",
-                 qchem_input_params=None,
-                 db_file=None,
-                 parents=None,
-                 **kwargs):
+    def __init__(
+        self,
+        molecule=None,
+        name="structure optimization",
+        qchem_cmd=">>qchem_cmd<<",
+        multimode=">>multimode<<",
+        max_cores=">>max_cores<<",
+        qchem_input_params=None,
+        db_file=None,
+        parents=None,
+        **kwargs
+    ):
         """
         Optimize the given structure.
 
@@ -140,15 +144,17 @@ class OptimizeFW(Firework):
         """
 
         qchem_input_params = qchem_input_params or {}
-        input_file="mol.qin"
-        output_file="mol.qout"
+        input_file = "mol.qin"
+        output_file = "mol.qout"
         t = []
         t.append(
             WriteInputFromIOSet(
                 molecule=molecule,
                 qchem_input_set="OptSet",
                 input_file=input_file,
-                qchem_input_params=qchem_input_params))
+                qchem_input_params=qchem_input_params,
+            )
+        )
         t.append(
             RunQChemCustodian(
                 qchem_cmd=qchem_cmd,
@@ -156,31 +162,33 @@ class OptimizeFW(Firework):
                 input_file=input_file,
                 output_file=output_file,
                 max_cores=max_cores,
-                job_type="normal"))
+                job_type="normal",
+            )
+        )
         t.append(
             QChemToDb(
                 db_file=db_file,
                 input_file=input_file,
                 output_file=output_file,
-                additional_fields={"task_label": name}))
-        super(OptimizeFW, self).__init__(
-            t,
-            parents=parents,
-            name=name,
-            **kwargs)
+                additional_fields={"task_label": name},
+            )
+        )
+        super().__init__(t, parents=parents, name=name, **kwargs)
 
 
 class FrequencyFW(Firework):
-    def __init__(self,
-                 molecule=None,
-                 name="frequency calculation",
-                 qchem_cmd=">>qchem_cmd<<",
-                 multimode=">>multimode<<",
-                 max_cores=">>max_cores<<",
-                 qchem_input_params=None,
-                 db_file=None,
-                 parents=None,
-                 **kwargs):
+    def __init__(
+        self,
+        molecule=None,
+        name="frequency calculation",
+        qchem_cmd=">>qchem_cmd<<",
+        multimode=">>multimode<<",
+        max_cores=">>max_cores<<",
+        qchem_input_params=None,
+        db_file=None,
+        parents=None,
+        **kwargs
+    ):
         """
         Optimize the given structure.
 
@@ -214,15 +222,17 @@ class FrequencyFW(Firework):
         """
 
         qchem_input_params = qchem_input_params or {}
-        input_file="mol.qin"
-        output_file="mol.qout"
+        input_file = "mol.qin"
+        output_file = "mol.qout"
         t = []
         t.append(
             WriteInputFromIOSet(
                 molecule=molecule,
                 qchem_input_set="FreqSet",
                 input_file=input_file,
-                qchem_input_params=qchem_input_params))
+                qchem_input_params=qchem_input_params,
+            )
+        )
         t.append(
             RunQChemCustodian(
                 qchem_cmd=qchem_cmd,
@@ -230,34 +240,36 @@ class FrequencyFW(Firework):
                 input_file=input_file,
                 output_file=output_file,
                 max_cores=max_cores,
-                job_type="normal"))
+                job_type="normal",
+            )
+        )
         t.append(
             QChemToDb(
                 db_file=db_file,
                 input_file=input_file,
                 output_file=output_file,
-                additional_fields={"task_label": name}))
-        super(FrequencyFW, self).__init__(
-            t,
-            parents=parents,
-            name=name,
-            **kwargs)
+                additional_fields={"task_label": name},
+            )
+        )
+        super().__init__(t, parents=parents, name=name, **kwargs)
 
 
 class FrequencyFlatteningOptimizeFW(Firework):
-    def __init__(self,
-                 molecule=None,
-                 name="frequency flattening structure optimization",
-                 qchem_cmd=">>qchem_cmd<<",
-                 multimode=">>multimode<<",
-                 max_cores=">>max_cores<<",
-                 qchem_input_params=None,
-                 max_iterations=10,
-                 max_molecule_perturb_scale=0.3,
-                 linked=True,
-                 db_file=None,
-                 parents=None,
-                 **kwargs):
+    def __init__(
+        self,
+        molecule=None,
+        name="frequency flattening structure optimization",
+        qchem_cmd=">>qchem_cmd<<",
+        multimode=">>multimode<<",
+        max_cores=">>max_cores<<",
+        qchem_input_params=None,
+        max_iterations=10,
+        max_molecule_perturb_scale=0.3,
+        linked=True,
+        db_file=None,
+        parents=None,
+        **kwargs
+    ):
         """
         Iteratively optimize the given structure and flatten imaginary frequencies to ensure that
         the resulting structure is a true minima and not a saddle point.
@@ -296,15 +308,17 @@ class FrequencyFlatteningOptimizeFW(Firework):
         """
 
         qchem_input_params = qchem_input_params or {}
-        input_file="mol.qin"
-        output_file="mol.qout"
+        input_file = "mol.qin"
+        output_file = "mol.qout"
         t = []
         t.append(
             WriteInputFromIOSet(
                 molecule=molecule,
                 qchem_input_set="OptSet",
                 input_file=input_file,
-                qchem_input_params=qchem_input_params))
+                qchem_input_params=qchem_input_params,
+            )
+        )
         t.append(
             RunQChemCustodian(
                 qchem_cmd=qchem_cmd,
@@ -315,7 +329,9 @@ class FrequencyFlatteningOptimizeFW(Firework):
                 job_type="opt_with_frequency_flattener",
                 max_iterations=max_iterations,
                 max_molecule_perturb_scale=max_molecule_perturb_scale,
-                linked=linked))
+                linked=linked,
+            )
+        )
         t.append(
             QChemToDb(
                 db_file=db_file,
@@ -324,29 +340,29 @@ class FrequencyFlatteningOptimizeFW(Firework):
                 additional_fields={
                     "task_label": name,
                     "special_run_type": "frequency_flattener",
-                    "linked": linked
-                }))
-        super(FrequencyFlatteningOptimizeFW, self).__init__(
-            t,
-            parents=parents,
-            name=name,
-            **kwargs)
+                    "linked": linked,
+                },
+            )
+        )
+        super().__init__(t, parents=parents, name=name, **kwargs)
 
 
 class FragmentFW(Firework):
-    def __init__(self,
-                 molecule=None,
-                 depth=1,
-                 open_rings=True,
-                 additional_charges=None,
-                 do_triplets=True,
-                 linked=False,
-                 name="fragment and optimize",
-                 qchem_input_params=None,
-                 db_file=None,
-                 check_db=True,
-                 parents=None,
-                 **kwargs):
+    def __init__(
+        self,
+        molecule=None,
+        depth=1,
+        open_rings=True,
+        additional_charges=None,
+        do_triplets=True,
+        linked=False,
+        name="fragment and optimize",
+        qchem_input_params=None,
+        db_file=None,
+        check_db=True,
+        parents=None,
+        **kwargs
+    ):
         """
         Fragment the given structure and optimize all unique fragments
 
@@ -398,25 +414,25 @@ class FragmentFW(Firework):
                 linked=linked,
                 qchem_input_params=qchem_input_params,
                 db_file=db_file,
-                check_db=check_db))
-        super(FragmentFW, self).__init__(
-            t,
-            parents=parents,
-            name=name,
-            **kwargs)
+                check_db=check_db,
+            )
+        )
+        super().__init__(t, parents=parents, name=name, **kwargs)
 
 
 class CubeAndCritic2FW(Firework):
-    def __init__(self,
-                 molecule=None,
-                 name="cube and critic2",
-                 qchem_cmd=">>qchem_cmd<<",
-                 multimode=">>multimode<<",
-                 max_cores=">>max_cores<<",
-                 qchem_input_params=None,
-                 db_file=None,
-                 parents=None,
-                 **kwargs):
+    def __init__(
+        self,
+        molecule=None,
+        name="cube and critic2",
+        qchem_cmd=">>qchem_cmd<<",
+        multimode=">>multimode<<",
+        max_cores=">>max_cores<<",
+        qchem_input_params=None,
+        db_file=None,
+        parents=None,
+        **kwargs
+    ):
         """
         Perform a Q-Chem single point calculation in order to generate a cube file of the electron density
         and then analyze the electron density critical points with the Critic2 package.
@@ -452,15 +468,17 @@ class CubeAndCritic2FW(Firework):
 
         qchem_input_params = copy.deepcopy(qchem_input_params) or {}
         qchem_input_params["plot_cubes"] = True
-        input_file="mol.qin"
-        output_file="mol.qout"
+        input_file = "mol.qin"
+        output_file = "mol.qout"
         t = []
         t.append(
             WriteInputFromIOSet(
                 molecule=molecule,
                 qchem_input_set="SinglePointSet",
                 input_file=input_file,
-                qchem_input_params=qchem_input_params))
+                qchem_input_params=qchem_input_params,
+            )
+        )
         t.append(
             RunQChemCustodian(
                 qchem_cmd=qchem_cmd,
@@ -468,22 +486,17 @@ class CubeAndCritic2FW(Firework):
                 input_file=input_file,
                 output_file=output_file,
                 max_cores=max_cores,
-                job_type="normal"))
-        t.append(
-            RunCritic2(
-                molecule=molecule,
-                cube_file="dens.0.cube.gz"))
-        t.append(
-            ProcessCritic2(
-                molecule=molecule))
+                job_type="normal",
+            )
+        )
+        t.append(RunCritic2(molecule=molecule, cube_file="dens.0.cube.gz"))
+        t.append(ProcessCritic2(molecule=molecule))
         t.append(
             QChemToDb(
                 db_file=db_file,
                 input_file=input_file,
                 output_file=output_file,
-                additional_fields={"task_label": name}))
-        super(CubeAndCritic2FW, self).__init__(
-            t,
-            parents=parents,
-            name=name,
-            **kwargs)
\ No newline at end of file
+                additional_fields={"task_label": name},
+            )
+        )
+        super().__init__(t, parents=parents, name=name, **kwargs)
