@@ -1,15 +1,23 @@
-# coding: utf-8
-
-
 import numpy as np
 
-__author__ = 'Kiran Mathew'
-__email__ = 'kmathew@lbl.gov'
+__author__ = "Kiran Mathew"
+__email__ = "kmathew@lbl.gov"
 
 # TODO: @matk86 - unit tests?
 
-def get_phonopy_gibbs(energies, volumes, force_constants, structure, t_min, t_step, t_max, mesh,
-                      eos, pressure=0):
+
+def get_phonopy_gibbs(
+    energies,
+    volumes,
+    force_constants,
+    structure,
+    t_min,
+    t_step,
+    t_max,
+    mesh,
+    eos,
+    pressure=0,
+):
     """
     Compute QHA gibbs free energy using the phonopy interface.
 
@@ -31,8 +39,18 @@ def get_phonopy_gibbs(energies, volumes, force_constants, structure, t_min, t_st
     """
 
     # quasi-harmonic approx
-    phonopy_qha = get_phonopy_qha(energies, volumes, force_constants, structure, t_min, t_step,
-                                  t_max, mesh, eos, pressure=pressure)
+    phonopy_qha = get_phonopy_qha(
+        energies,
+        volumes,
+        force_constants,
+        structure,
+        t_min,
+        t_step,
+        t_max,
+        mesh,
+        eos,
+        pressure=pressure,
+    )
 
     # gibbs free energy and temperature
     max_t_index = phonopy_qha._qha._max_t_index
@@ -41,8 +59,18 @@ def get_phonopy_gibbs(energies, volumes, force_constants, structure, t_min, t_st
     return G, T
 
 
-def get_phonopy_qha(energies, volumes, force_constants, structure, t_min, t_step, t_max, mesh, eos,
-                      pressure=0):
+def get_phonopy_qha(
+    energies,
+    volumes,
+    force_constants,
+    structure,
+    t_min,
+    t_step,
+    t_max,
+    mesh,
+    eos,
+    pressure=0,
+):
     """
     Return phonopy QHA interface.
 
@@ -67,9 +95,11 @@ def get_phonopy_qha(energies, volumes, force_constants, structure, t_min, t_step
     from phonopy import PhonopyQHA
     from phonopy.units import EVAngstromToGPa
 
-    phon_atoms = PhonopyAtoms(symbols=[str(s.specie) for s in structure],
-                              scaled_positions=structure.frac_coords,
-                              cell=structure.lattice.matrix)
+    phon_atoms = PhonopyAtoms(
+        symbols=[str(s.specie) for s in structure],
+        scaled_positions=structure.frac_coords,
+        cell=structure.lattice.matrix,
+    )
     scell = [[1, 0, 0], [0, 1, 0], [0, 0, 1]]
     phonon = Phonopy(phon_atoms, scell)
     # compute the required phonon thermal properties
@@ -90,13 +120,30 @@ def get_phonopy_qha(energies, volumes, force_constants, structure, t_min, t_step
     # add pressure contribution
     energies = np.array(energies) + np.array(volumes) * pressure / EVAngstromToGPa
     # quasi-harmonic approx
-    return PhonopyQHA(volumes, energies, eos=eos, temperatures=temperatures[0],
-                      free_energy=np.array(free_energy).T, cv=np.array(cv).T,
-                      entropy=np.array(entropy).T, t_max=np.max(temperatures[0]))
+    return PhonopyQHA(
+        volumes,
+        energies,
+        eos=eos,
+        temperatures=temperatures[0],
+        free_energy=np.array(free_energy).T,
+        cv=np.array(cv).T,
+        entropy=np.array(entropy).T,
+        t_max=np.max(temperatures[0]),
+    )
 
 
-def get_phonopy_thermal_expansion(energies, volumes, force_constants, structure, t_min, t_step,
-                                  t_max, mesh, eos, pressure=0):
+def get_phonopy_thermal_expansion(
+    energies,
+    volumes,
+    force_constants,
+    structure,
+    t_min,
+    t_step,
+    t_max,
+    mesh,
+    eos,
+    pressure=0,
+):
     """
     Compute QHA thermal expansion coefficient using the phonopy interface.
 
@@ -118,8 +165,18 @@ def get_phonopy_thermal_expansion(energies, volumes, force_constants, structure,
     """
 
     # quasi-harmonic approx
-    phonopy_qha = get_phonopy_qha(energies, volumes, force_constants, structure, t_min, t_step,
-                                  t_max, mesh, eos, pressure=pressure)
+    phonopy_qha = get_phonopy_qha(
+        energies,
+        volumes,
+        force_constants,
+        structure,
+        t_min,
+        t_step,
+        t_max,
+        mesh,
+        eos,
+        pressure=pressure,
+    )
 
     # thermal expansion coefficient and temperature
     max_t_index = phonopy_qha._qha._max_t_index
