@@ -1,6 +1,3 @@
-# coding: utf-8
-
-
 from atomate.utils.utils import get_database
 
 from atomate.utils.utils import get_logger
@@ -8,7 +5,7 @@ from atomate.vasp.builders.base import AbstractBuilder
 
 logger = get_logger(__name__)
 
-__author__ = 'Anubhav Jain <ajain@lbl.gov>'
+__author__ = "Anubhav Jain <ajain@lbl.gov>"
 
 
 class FixTasksBuilder(AbstractBuilder):
@@ -24,34 +21,63 @@ class FixTasksBuilder(AbstractBuilder):
     def run(self):
         # change spacegroup numbers from string to integer where needed
         logger.info("FixTasksBuilder started.")
-        for t in self._tasks.find({"output.spacegroup.number": {"$type": 2}},
-                                  {"task_id": 1, "output": 1}):
+        for t in self._tasks.find(
+            {"output.spacegroup.number": {"$type": 2}}, {"task_id": 1, "output": 1}
+        ):
             logger.info("Fixing string spacegroup, tid: {}".format(t["task_id"]))
             sg = int(t["output"]["spacegroup"]["number"])
-            self._tasks.update_one({"task_id": t["task_id"]},
-                                   {"$set": {"output.spacegroup.number": sg}})
+            self._tasks.update_one(
+                {"task_id": t["task_id"]}, {"$set": {"output.spacegroup.number": sg}}
+            )
 
         # change tags from string to list where needed
-        for t in self._tasks.find({"tags": {"$exists": True}, "tags.0": {"$exists": False}}, {"task_id": 1, "tags": 1}):
+        for t in self._tasks.find(
+            {"tags": {"$exists": True}, "tags.0": {"$exists": False}},
+            {"task_id": 1, "tags": 1},
+        ):
             logger.info("Fixing tag (converting to list), tid: {}".format(t["task_id"]))
-            self._tasks.update_one({"task_id": t["task_id"]},
-                                   {"$set": {"tags": [t["tags"]]}})
+            self._tasks.update_one(
+                {"task_id": t["task_id"]}, {"$set": {"tags": [t["tags"]]}}
+            )
 
         # fix old (incorrect) delta volume percent
-        for t in self._tasks.find({"analysis.delta_volume_percent": {"$exists": True}, "analysis.delta_volume_as_percent": {"$exists": False}}, {"task_id": 1, "analysis": 1}):
-            logger.info("Converting delta_volume_percent to be on a percentage scale, tid: {}".format(t["task_id"]))
-            self._tasks.update_one({"task_id": t["task_id"]},
-                                   {"$set": {"analysis.delta_volume_as_percent": t["analysis"]["delta_volume_percent"] * 100}})
+        for t in self._tasks.find(
+            {
+                "analysis.delta_volume_percent": {"$exists": True},
+                "analysis.delta_volume_as_percent": {"$exists": False},
+            },
+            {"task_id": 1, "analysis": 1},
+        ):
+            logger.info(
+                "Converting delta_volume_percent to be on a percentage scale, tid: {}".format(
+                    t["task_id"]
+                )
+            )
+            self._tasks.update_one(
+                {"task_id": t["task_id"]},
+                {
+                    "$set": {
+                        "analysis.delta_volume_as_percent": t["analysis"][
+                            "delta_volume_percent"
+                        ]
+                        * 100
+                    }
+                },
+            )
 
         # remove old (incorrect) delta volume percent
         for t in self._tasks.find(
-                {"analysis.delta_volume_percent": {"$exists": True},
-                 "analysis.delta_volume_as_percent": {"$exists": True}},
-                {"task_id": 1}):
+            {
+                "analysis.delta_volume_percent": {"$exists": True},
+                "analysis.delta_volume_as_percent": {"$exists": True},
+            },
+            {"task_id": 1},
+        ):
             logger.info("Removing delta_volume_percent, tid: {}".format(t["task_id"]))
-            self._tasks.update_one({"task_id": t["task_id"]},
-                                   {"$unset": {"analysis.delta_volume_percent": 1}})
-
+            self._tasks.update_one(
+                {"task_id": t["task_id"]},
+                {"$unset": {"analysis.delta_volume_percent": 1}},
+            )
 
         logger.info("FixTasksBuilder finished.")
 
