@@ -1,6 +1,3 @@
-# coding: utf-8
-
-
 """
 This Drone tries to produce a more sensible task dictionary than the default VaspToDbTaskDrone.
 Some of the changes are documented in this thread:
@@ -38,7 +35,7 @@ from atomate.utils.utils import get_uri
 
 from atomate.utils.utils import get_logger
 from atomate import __version__ as atomate_version
-from atomate.vasp.config import STORE_VOLUMETRIC_DATA, STORE_ADDITIONAL_JSON
+from atomate.vasp.config import STORE_VOLUMETRIC_DATA, STORE_ADDITIONAL_JSON, STORE_BADER
 
 __author__ = "Kiran Mathew, Shyue Ping Ong, Shyam Dwaraknath, Anubhav Jain"
 __email__ = "kmathew@lbl.gov"
@@ -47,7 +44,9 @@ __version__ = "0.1.0"
 
 logger = get_logger(__name__)
 
-BADER_EXE_EXISTS = which("bader") or which("bader.exe")
+BADER_EXE_EXISTS = (which("bader") or which("bader.exe"))
+STORE_BADER = STORE_BADER and BADER_EXE_EXISTS
+
 
 
 class VaspDrone(AbstractDrone):
@@ -138,7 +137,7 @@ class VaspDrone(AbstractDrone):
         parse_locpot=True,
         additional_fields=None,
         use_full_uri=True,
-        parse_bader=BADER_EXE_EXISTS,
+        parse_bader=STORE_BADER,
         parse_chgcar=False,
         parse_aeccar=False,
         parse_potcar_file=True,
@@ -212,7 +211,7 @@ class VaspDrone(AbstractDrone):
         Returns:
             (dict): a task dictionary
         """
-        logger.info("Getting task doc for base dir :{}".format(path))
+        logger.info(f"Getting task doc for base dir :{path}")
         vasprun_files = self.filter_files(path, file_pattern="vasprun.xml")
         outcar_files = self.filter_files(path, file_pattern="OUTCAR")
         if len(vasprun_files) > 0 and len(outcar_files) > 0:
@@ -246,17 +245,17 @@ class VaspDrone(AbstractDrone):
             # try subfolder schema
             if r in files:
                 for f in os.listdir(os.path.join(path, r)):
-                    if fnmatch(f, "{}*".format(file_pattern)):
+                    if fnmatch(f, f"{file_pattern}*"):
                         processed_files[r] = os.path.join(r, f)
             # try extension schema
             else:
                 for f in files:
-                    if fnmatch(f, "{}.{}*".format(file_pattern, r)):
+                    if fnmatch(f, f"{file_pattern}.{r}*"):
                         processed_files[r] = f
         if len(processed_files) == 0:
             # get any matching file from the folder
             for f in files:
-                if fnmatch(f, "{}*".format(file_pattern)):
+                if fnmatch(f, f"{file_pattern}*"):
                     processed_files["standard"] = f
         return processed_files
 
@@ -296,7 +295,7 @@ class VaspDrone(AbstractDrone):
                     overall_run_stats[key] = sum([v[key] for v in run_stats.values()])
                 run_stats["overall"] = overall_run_stats
             except Exception:
-                logger.error("Bad run stats for {}.".format(fullpath))
+                logger.error(f"Bad run stats for {fullpath}.")
             d["run_stats"] = run_stats
 
             # reverse the calculations data order so newest calc is first
@@ -575,7 +574,7 @@ class VaspDrone(AbstractDrone):
 
         # perform Bader analysis using Henkelman bader
         if self.parse_bader and "chgcar" in d["output_file_paths"]:
-            suffix = "" if taskname == "standard" else ".{}".format(taskname)
+            suffix = "" if taskname == "standard" else f".{taskname}"
             bader = bader_analysis_from_path(dir_name, suffix=suffix)
             d["bader"] = bader
 
@@ -736,7 +735,7 @@ class VaspDrone(AbstractDrone):
             d:
                 Current doc generated.
         """
-        logger.info("Post-processing dir:{}".format(dir_name))
+        logger.info(f"Post-processing dir:{dir_name}")
         fullpath = os.path.abspath(dir_name)
         # VASP input generated by pymatgen's alchemy has a transformations.json file that tracks
         # the origin of a particular structure. If such a file is found, it is inserted into the
@@ -828,7 +827,7 @@ class VaspDrone(AbstractDrone):
             else:
                 diff = v.difference(set(d.get(k, d).keys()))
             if diff:
-                logger.warning("The keys {0} in {1} not set".format(diff, k))
+                logger.warning(f"The keys {diff} in {k} not set")
 
     def get_valid_paths(self, path):
         """
