@@ -1,5 +1,3 @@
-# coding: utf-8
-
 import glob
 import warnings
 
@@ -24,13 +22,17 @@ from pymatgen.core.structure import Structure
 from fireworks import explicit_serialize, FiretaskBase, FWAction
 
 from atomate.utils.utils import env_chk, get_logger
-from atomate.common.firetasks.glue_tasks import get_calc_loc, PassResult, \
-    CopyFiles, CopyFilesFromCalcLoc
+from atomate.common.firetasks.glue_tasks import (
+    get_calc_loc,
+    PassResult,
+    CopyFiles,
+    CopyFilesFromCalcLoc,
+)
 
 logger = get_logger(__name__)
 
-__author__ = 'Anubhav Jain, Kiran Mathew'
-__email__ = 'ajain@lbl.gov, kmathew@lbl.gov'
+__author__ = "Anubhav Jain, Kiran Mathew"
+__email__ = "ajain@lbl.gov, kmathew@lbl.gov"
 
 
 @explicit_serialize
@@ -64,20 +66,34 @@ class CopyVaspOutputs(CopyFiles):
             Default: False
     """
 
-    optional_params = ["calc_loc", "calc_dir", "filesystem", "additional_files",
-                       "contcar_to_poscar", "potcar_spec"]
+    optional_params = [
+        "calc_loc",
+        "calc_dir",
+        "filesystem",
+        "additional_files",
+        "contcar_to_poscar",
+        "potcar_spec",
+    ]
 
     def run_task(self, fw_spec):
 
-        calc_loc = get_calc_loc(self["calc_loc"],
-                                fw_spec["calc_locs"]) if self.get(
-            "calc_loc") else {}
+        calc_loc = (
+            get_calc_loc(self["calc_loc"], fw_spec["calc_locs"])
+            if self.get("calc_loc")
+            else {}
+        )
 
         # determine what files need to be copied
         files_to_copy = None
         if "$ALL" not in self.get("additional_files", []):
-            files_to_copy = ['INCAR', 'POSCAR', 'KPOINTS', 'POTCAR', 'OUTCAR',
-                             'vasprun.xml']
+            files_to_copy = [
+                "INCAR",
+                "POSCAR",
+                "KPOINTS",
+                "POTCAR",
+                "OUTCAR",
+                "vasprun.xml",
+            ]
             if self.get("additional_files"):
                 files_to_copy.extend(self["additional_files"])
             if self.get("potcar_spec", False):
@@ -88,13 +104,15 @@ class CopyVaspOutputs(CopyFiles):
         contcar_to_poscar = self.get("contcar_to_poscar", True)
         if contcar_to_poscar and "CONTCAR" not in files_to_copy:
             files_to_copy.append("CONTCAR")
-            files_to_copy = [f for f in files_to_copy if
-                             f != 'POSCAR']  # remove POSCAR
+            files_to_copy = [f for f in files_to_copy if f != "POSCAR"]  # remove POSCAR
 
         # setup the copy
-        self.setup_copy(self.get("calc_dir", None),
-                        filesystem=self.get("filesystem", None),
-                        files_to_copy=files_to_copy, from_path_dict=calc_loc)
+        self.setup_copy(
+            self.get("calc_dir", None),
+            filesystem=self.get("filesystem", None),
+            files_to_copy=files_to_copy,
+            from_path_dict=calc_loc,
+        )
         # do the copying
         self.copy_files()
 
@@ -103,18 +121,21 @@ class CopyVaspOutputs(CopyFiles):
         # start file copy
         for f in self.files_to_copy:
             prev_path_full = os.path.join(self.from_dir, f)
-            dest_fname = 'POSCAR' if f == 'CONTCAR' and self.get(
-                "contcar_to_poscar", True) else f
+            dest_fname = (
+                "POSCAR"
+                if f == "CONTCAR" and self.get("contcar_to_poscar", True)
+                else f
+            )
             dest_path = os.path.join(self.to_dir, dest_fname)
 
             relax_ext = ""
-            relax_paths = sorted(
-                self.fileclient.glob(prev_path_full + ".relax*"))
+            relax_paths = sorted(self.fileclient.glob(prev_path_full + ".relax*"))
             if relax_paths:
                 if len(relax_paths) > 9:
                     raise ValueError(
-                        "CopyVaspOutputs doesn't properly handle >9 relaxations!")
-                m = re.search('\.relax\d*', relax_paths[-1])
+                        "CopyVaspOutputs doesn't properly handle >9 relaxations!"
+                    )
+                m = re.search(r"\.relax\d*", relax_paths[-1])
                 relax_ext = m.group(0)
 
             # detect .gz extension if needed - note that monty zpath() did not seem useful here
@@ -127,20 +148,23 @@ class CopyVaspOutputs(CopyFiles):
             if not (f + relax_ext + gz_ext) in all_files:
                 # do not fail if KPOINTS is missing, because this might indicate use of automatic
                 # KPOINTS (e.g., KSPACING argument)
-                if f == 'KPOINTS':
-                    warnings.warn("Cannot find file: {}".format(f))
+                if f == "KPOINTS":
+                    warnings.warn(f"Cannot find file: {f}")
                     continue
                 else:
-                    raise ValueError("Cannot find file: {}".format(f))
+                    raise ValueError(f"Cannot find file: {f}")
 
             # copy the file (minus the relaxation extension)
-            self.fileclient.copy(prev_path_full + relax_ext + gz_ext,
-                                 dest_path + gz_ext)
+            self.fileclient.copy(
+                prev_path_full + relax_ext + gz_ext, dest_path + gz_ext
+            )
 
             # unzip the .gz if needed
-            if gz_ext in ['.gz', ".GZ"]:
+            if gz_ext in [".gz", ".GZ"]:
                 # unzip dest file
-                with open(dest_path, 'wb') as f_out, gzip.open(dest_path + gz_ext, 'rb') as f_in:
+                with open(dest_path, "wb") as f_out, gzip.open(
+                    dest_path + gz_ext, "rb"
+                ) as f_in:
                     shutil.copyfileobj(f_in, f_out)
                 os.remove(dest_path + gz_ext)
 
@@ -167,17 +191,16 @@ class CheckStability(FiretaskBase):
 
     def run_task(self, fw_spec):
         mpr = MPRester(env_chk(self.get("MAPI_KEY"), fw_spec))
-        vasprun, outcar = get_vasprun_outcar(self.get("calc_dir", "."),
-                                             parse_dos=False,
-                                             parse_eigen=False)
+        vasprun, outcar = get_vasprun_outcar(
+            self.get("calc_dir", "."), parse_dos=False, parse_eigen=False
+        )
 
         my_entry = vasprun.get_computed_entry(inc_structure=False)
         stored_data = mpr.get_stability([my_entry])[0]
 
         if stored_data["e_above_hull"] > self.get("ehull_cutoff", 0.05):
             logger.info("CheckStability: failed test!")
-            return FWAction(stored_data=stored_data, exit=True,
-                            defuse_workflow=True)
+            return FWAction(stored_data=stored_data, exit=True, defuse_workflow=True)
 
         else:
             return FWAction(stored_data=stored_data)
@@ -211,21 +234,21 @@ class CheckBandgap(FiretaskBase):
             if relax_paths:
                 if len(relax_paths) > 9:
                     raise ValueError(
-                        "CheckBandgap doesn't properly handle >9 relaxations!")
+                        "CheckBandgap doesn't properly handle >9 relaxations!"
+                    )
                 vr_path = relax_paths[-1]
 
-        logger.info("Checking the gap of file: {}".format(vr_path))
+        logger.info(f"Checking the gap of file: {vr_path}")
         vr = Vasprun(vr_path, parse_potcar_file=False)
         gap = vr.get_band_structure().get_band_gap()["energy"]
         stored_data = {"band_gap": gap}
         logger.info(
-            "The gap is: {}. Min gap: {}. Max gap: {}".format(gap, min_gap,
-                                                              max_gap))
+            "The gap is: {}. Min gap: {}. Max gap: {}".format(gap, min_gap, max_gap)
+        )
 
         if (min_gap and gap < min_gap) or (max_gap and gap > max_gap):
             logger.info("CheckBandgap: failed test!")
-            return FWAction(stored_data=stored_data, exit=True,
-                            defuse_workflow=True)
+            return FWAction(stored_data=stored_data, exit=True, defuse_workflow=True)
 
         return FWAction(stored_data=stored_data)
 
@@ -256,6 +279,7 @@ class GetInterpolatedPOSCAR(FiretaskBase):
           points in this particular structure. Default is 0.0.
 
     """
+
     required_params = ["start", "end", "this_image", "nimages"]
     optional_params = ["autosort_tol"]
 
@@ -265,26 +289,34 @@ class GetInterpolatedPOSCAR(FiretaskBase):
 
     def interpolate_poscar(self, fw_spec):
         # make folder for poscar interpolation start and end structure files.
-        interpolate_folder = 'interpolate'
+        interpolate_folder = "interpolate"
         if not os.path.exists(os.path.join(os.getcwd(), interpolate_folder)):
             os.makedirs(os.path.join(os.getcwd(), interpolate_folder))
 
         # use CopyFilesFromCalcLoc to get files from previous locations.
-        CopyFilesFromCalcLoc(calc_loc=self["start"],
-                             filenames=["CONTCAR"],
-                             name_prepend=interpolate_folder + os.sep,
-                             name_append="_0").run_task(fw_spec=fw_spec)
-        CopyFilesFromCalcLoc(calc_loc=self["end"],
-                             filenames=["CONTCAR"],
-                             name_prepend=interpolate_folder + os.sep,
-                             name_append="_1").run_task(fw_spec=fw_spec)
+        CopyFilesFromCalcLoc(
+            calc_loc=self["start"],
+            filenames=["CONTCAR"],
+            name_prepend=interpolate_folder + os.sep,
+            name_append="_0",
+        ).run_task(fw_spec=fw_spec)
+        CopyFilesFromCalcLoc(
+            calc_loc=self["end"],
+            filenames=["CONTCAR"],
+            name_prepend=interpolate_folder + os.sep,
+            name_append="_1",
+        ).run_task(fw_spec=fw_spec)
 
         # assuming first calc_dir is polar structure for ferroelectric search
         s1 = Structure.from_file(os.path.join(interpolate_folder, "CONTCAR_0"))
         s2 = Structure.from_file(os.path.join(interpolate_folder, "CONTCAR_1"))
 
-        structs = s1.interpolate(s2, self["nimages"], interpolate_lattices=True,
-                                 autosort_tol=self.get("autosort_tol", 0.0))
+        structs = s1.interpolate(
+            s2,
+            self["nimages"],
+            interpolate_lattices=True,
+            autosort_tol=self.get("autosort_tol", 0.0),
+        )
 
         # save only the interpolation needed for this run
 
@@ -292,9 +324,14 @@ class GetInterpolatedPOSCAR(FiretaskBase):
         return structs[i]
 
 
-def pass_vasp_result(pass_dict=None, calc_dir='.', filename="vasprun.xml.gz",
-                     parse_eigen=False,
-                     parse_dos=False, **kwargs):
+def pass_vasp_result(
+    pass_dict=None,
+    calc_dir=".",
+    filename="vasprun.xml.gz",
+    parse_eigen=False,
+    parse_dos=False,
+    **kwargs,
+):
     """
     Function that gets a PassResult firework corresponding to output from a Vasprun.  Covers
     most use cases in which user needs to pass results from a vasp run to child FWs
@@ -326,8 +363,15 @@ def pass_vasp_result(pass_dict=None, calc_dir='.', filename="vasprun.xml.gz",
 
     """
     pass_dict = pass_dict or {"computed_entry": "a>>get_computed_entry"}
-    parse_kwargs = {"filename": filename, "parse_eigen": parse_eigen,
-                    "parse_dos": parse_dos}
-    return PassResult(pass_dict=pass_dict, calc_dir=calc_dir,
-                      parse_kwargs=parse_kwargs,
-                      parse_class="pymatgen.io.vasp.outputs.Vasprun", **kwargs)
+    parse_kwargs = {
+        "filename": filename,
+        "parse_eigen": parse_eigen,
+        "parse_dos": parse_dos,
+    }
+    return PassResult(
+        pass_dict=pass_dict,
+        calc_dir=calc_dir,
+        parse_kwargs=parse_kwargs,
+        parse_class="pymatgen.io.vasp.outputs.Vasprun",
+        **kwargs,
+    )
