@@ -1,6 +1,3 @@
-# coding: utf-8
-
-
 from monty.os.path import zpath
 from monty.serialization import loadfn
 
@@ -20,10 +17,23 @@ from pymatgen.io.vasp.sets import get_vasprun_outcar
 from pymatgen.electronic_structure.boltztrap import BoltztrapRunner
 
 from custodian import Custodian
-from custodian.vasp.handlers import VaspErrorHandler, AliasingErrorHandler, \
-    MeshSymmetryErrorHandler, UnconvergedErrorHandler, MaxForceErrorHandler, PotimErrorHandler, \
-    FrozenJobErrorHandler, NonConvergingErrorHandler, PositiveEnergyErrorHandler, \
-    WalltimeHandler, StdErrHandler, DriftErrorHandler, LargeSigmaHandler, IncorrectSmearingHandler, ScanMetalHandler
+from custodian.vasp.handlers import (
+    VaspErrorHandler,
+    AliasingErrorHandler,
+    MeshSymmetryErrorHandler,
+    UnconvergedErrorHandler,
+    MaxForceErrorHandler,
+    PotimErrorHandler,
+    FrozenJobErrorHandler,
+    NonConvergingErrorHandler,
+    PositiveEnergyErrorHandler,
+    WalltimeHandler,
+    StdErrHandler,
+    DriftErrorHandler,
+    LargeSigmaHandler,
+    IncorrectSmearingHandler,
+    ScanMetalHandler,
+)
 from custodian.vasp.jobs import VaspJob, VaspNEBJob
 from custodian.vasp.validators import VasprunXMLValidator, VaspFilesValidator
 
@@ -32,8 +42,8 @@ from fireworks import explicit_serialize, FiretaskBase, FWAction
 from atomate.utils.utils import env_chk, get_logger
 from atomate.vasp.config import CUSTODIAN_MAX_ERRORS
 
-__author__ = 'Anubhav Jain <ajain@lbl.gov>'
-__credits__ = 'Shyue Ping Ong <ong.sp>'
+__author__ = "Anubhav Jain <ajain@lbl.gov>"
+__credits__ = "Shyue Ping Ong <ong.sp>"
 
 logger = get_logger(__name__)
 
@@ -57,9 +67,9 @@ class RunVaspDirect(FiretaskBase):
         if self.get("expand_vars", False):
             cmd = os.path.expandvars(cmd)
 
-        logger.info("Running command: {}".format(cmd))
+        logger.info(f"Running command: {cmd}")
         return_code = subprocess.call(cmd, shell=True)
-        logger.info("Command {} finished running with returncode: {}".format(cmd, return_code))
+        logger.info(f"Command {cmd} finished running with returncode: {return_code}")
 
 
 @explicit_serialize
@@ -90,30 +100,67 @@ class RunVaspCustodian(FiretaskBase):
         wall_time (int): Total wall time in seconds. Activates WalltimeHandler if set.
         half_kpts_first_relax (bool): Use half the k-points for the first relaxation
     """
+
     required_params = ["vasp_cmd"]
-    optional_params = ["job_type", "handler_group", "max_force_threshold", "scratch_dir",
-                       "gzip_output", "max_errors", "ediffg", "auto_npar", "gamma_vasp_cmd",
-                       "wall_time","half_kpts_first_relax"]
+    optional_params = [
+        "job_type",
+        "handler_group",
+        "max_force_threshold",
+        "scratch_dir",
+        "gzip_output",
+        "max_errors",
+        "ediffg",
+        "auto_npar",
+        "gamma_vasp_cmd",
+        "wall_time",
+        "half_kpts_first_relax",
+    ]
 
     def run_task(self, fw_spec):
 
         handler_groups = {
-            "default": [VaspErrorHandler(), MeshSymmetryErrorHandler(), UnconvergedErrorHandler(),
-                        NonConvergingErrorHandler(), PotimErrorHandler(),
-                        PositiveEnergyErrorHandler(), FrozenJobErrorHandler(), StdErrHandler(),
-                        LargeSigmaHandler(), IncorrectSmearingHandler()],
-            "strict": [VaspErrorHandler(), MeshSymmetryErrorHandler(), UnconvergedErrorHandler(),
-                       NonConvergingErrorHandler(), PotimErrorHandler(),
-                       PositiveEnergyErrorHandler(), FrozenJobErrorHandler(),
-                       StdErrHandler(), AliasingErrorHandler(), DriftErrorHandler(), LargeSigmaHandler(), 
-                       IncorrectSmearingHandler()],
-            "scan": [VaspErrorHandler(), MeshSymmetryErrorHandler(), UnconvergedErrorHandler(),
-                     NonConvergingErrorHandler(), PotimErrorHandler(),
-                     PositiveEnergyErrorHandler(), FrozenJobErrorHandler(), StdErrHandler(),
-                     LargeSigmaHandler(), IncorrectSmearingHandler(), ScanMetalHandler()],
+            "default": [
+                VaspErrorHandler(),
+                MeshSymmetryErrorHandler(),
+                UnconvergedErrorHandler(),
+                NonConvergingErrorHandler(),
+                PotimErrorHandler(),
+                PositiveEnergyErrorHandler(),
+                FrozenJobErrorHandler(),
+                StdErrHandler(),
+                LargeSigmaHandler(),
+                IncorrectSmearingHandler(),
+            ],
+            "strict": [
+                VaspErrorHandler(),
+                MeshSymmetryErrorHandler(),
+                UnconvergedErrorHandler(),
+                NonConvergingErrorHandler(),
+                PotimErrorHandler(),
+                PositiveEnergyErrorHandler(),
+                FrozenJobErrorHandler(),
+                StdErrHandler(),
+                AliasingErrorHandler(),
+                DriftErrorHandler(),
+                LargeSigmaHandler(),
+                IncorrectSmearingHandler(),
+            ],
+            "scan": [
+                VaspErrorHandler(),
+                MeshSymmetryErrorHandler(),
+                UnconvergedErrorHandler(),
+                NonConvergingErrorHandler(),
+                PotimErrorHandler(),
+                PositiveEnergyErrorHandler(),
+                FrozenJobErrorHandler(),
+                StdErrHandler(),
+                LargeSigmaHandler(),
+                IncorrectSmearingHandler(),
+                ScanMetalHandler(),
+            ],
             "md": [VaspErrorHandler(), NonConvergingErrorHandler()],
-            "no_handler": []
-            }
+            "no_handler": [],
+        }
 
         vasp_cmd = env_chk(self["vasp_cmd"], fw_spec)
 
@@ -127,29 +174,55 @@ class RunVaspCustodian(FiretaskBase):
         gzip_output = self.get("gzip_output", True)
         max_errors = self.get("max_errors", CUSTODIAN_MAX_ERRORS)
         auto_npar = env_chk(self.get("auto_npar"), fw_spec, strict=False, default=False)
-        gamma_vasp_cmd = env_chk(self.get("gamma_vasp_cmd"), fw_spec, strict=False, default=None)
+        gamma_vasp_cmd = env_chk(
+            self.get("gamma_vasp_cmd"), fw_spec, strict=False, default=None
+        )
         if gamma_vasp_cmd:
             gamma_vasp_cmd = shlex.split(gamma_vasp_cmd)
 
         # construct jobs
         if job_type == "normal":
-            jobs = [VaspJob(vasp_cmd, auto_npar=auto_npar, gamma_vasp_cmd=gamma_vasp_cmd)]
+            jobs = [
+                VaspJob(vasp_cmd, auto_npar=auto_npar, gamma_vasp_cmd=gamma_vasp_cmd)
+            ]
         elif job_type == "normal_no_backup":
-            jobs = [VaspJob(vasp_cmd, auto_npar=auto_npar, gamma_vasp_cmd=gamma_vasp_cmd,backup=False)]
+            jobs = [
+                VaspJob(
+                    vasp_cmd,
+                    auto_npar=auto_npar,
+                    gamma_vasp_cmd=gamma_vasp_cmd,
+                    backup=False,
+                )
+            ]
         elif job_type == "double_relaxation_run":
-            jobs = VaspJob.double_relaxation_run(vasp_cmd, auto_npar=auto_npar,
-                                                 ediffg=self.get("ediffg"),
-                                                 half_kpts_first_relax=self.get("half_kpts_first_relax", HALF_KPOINTS_FIRST_RELAX))
+            jobs = VaspJob.double_relaxation_run(
+                vasp_cmd,
+                auto_npar=auto_npar,
+                ediffg=self.get("ediffg"),
+                half_kpts_first_relax=self.get(
+                    "half_kpts_first_relax", HALF_KPOINTS_FIRST_RELAX
+                ),
+            )
         elif job_type == "metagga_opt_run":
-            jobs = VaspJob.metagga_opt_run(vasp_cmd, auto_npar=auto_npar,
-                                                 ediffg=self.get("ediffg"),
-                                                 half_kpts_first_relax=self.get("half_kpts_first_relax", HALF_KPOINTS_FIRST_RELAX))
+            jobs = VaspJob.metagga_opt_run(
+                vasp_cmd,
+                auto_npar=auto_npar,
+                ediffg=self.get("ediffg"),
+                half_kpts_first_relax=self.get(
+                    "half_kpts_first_relax", HALF_KPOINTS_FIRST_RELAX
+                ),
+            )
 
         elif job_type == "full_opt_run":
-            jobs = VaspJob.full_opt_run(vasp_cmd, auto_npar=auto_npar,
-                                        ediffg=self.get("ediffg"),
-                                        max_steps=9,
-                                        half_kpts_first_relax=self.get("half_kpts_first_relax", HALF_KPOINTS_FIRST_RELAX))
+            jobs = VaspJob.full_opt_run(
+                vasp_cmd,
+                auto_npar=auto_npar,
+                ediffg=self.get("ediffg"),
+                max_steps=9,
+                half_kpts_first_relax=self.get(
+                    "half_kpts_first_relax", HALF_KPOINTS_FIRST_RELAX
+                ),
+            )
         elif job_type == "neb":
             # TODO: @shyuep @HanmeiTang This means that NEB can only be run (i) in reservation mode
             # and (ii) when the queueadapter parameter is overridden and (iii) the queue adapter
@@ -170,20 +243,26 @@ class RunVaspCustodian(FiretaskBase):
             # -computron
 
             # Index the tag "-n" or "-np"
-            index = [i for i, s in enumerate(vasp_cmd) if '-n' in s]
+            index = [i for i, s in enumerate(vasp_cmd) if "-n" in s]
             ppn = int(vasp_cmd[index[0] + 1])
             vasp_cmd[index[0] + 1] = str(nnodes * ppn)
 
             # Do the same for gamma_vasp_cmd
             if gamma_vasp_cmd:
-                index = [i for i, s in enumerate(gamma_vasp_cmd) if '-n' in s]
+                index = [i for i, s in enumerate(gamma_vasp_cmd) if "-n" in s]
                 ppn = int(gamma_vasp_cmd[index[0] + 1])
                 gamma_vasp_cmd[index[0] + 1] = str(nnodes * ppn)
 
-            jobs = [VaspNEBJob(vasp_cmd, final=False, auto_npar=auto_npar,
-                               gamma_vasp_cmd=gamma_vasp_cmd)]
+            jobs = [
+                VaspNEBJob(
+                    vasp_cmd,
+                    final=False,
+                    auto_npar=auto_npar,
+                    gamma_vasp_cmd=gamma_vasp_cmd,
+                )
+            ]
         else:
-            raise ValueError("Unsupported job type: {}".format(job_type))
+            raise ValueError(f"Unsupported job type: {job_type}")
 
         # construct handlers
 
@@ -194,18 +273,28 @@ class RunVaspCustodian(FiretaskBase):
             handlers = handler_group
 
         if self.get("max_force_threshold"):
-            handlers.append(MaxForceErrorHandler(max_force_threshold=self["max_force_threshold"]))
+            handlers.append(
+                MaxForceErrorHandler(max_force_threshold=self["max_force_threshold"])
+            )
 
         if self.get("wall_time"):
             handlers.append(WalltimeHandler(wall_time=self["wall_time"]))
 
         if job_type == "neb":
-            validators = []  # CINEB vasprun.xml sometimes incomplete, file structure different
+            validators = (
+                []
+            )  # CINEB vasprun.xml sometimes incomplete, file structure different
         else:
             validators = [VasprunXMLValidator(), VaspFilesValidator()]
 
-        c = Custodian(handlers, jobs, validators=validators, max_errors=max_errors,
-                      scratch_dir=scratch_dir, gzipped_output=gzip_output)
+        c = Custodian(
+            handlers,
+            jobs,
+            validators=validators,
+            max_errors=max_errors,
+            scratch_dir=scratch_dir,
+            gzipped_output=gzip_output,
+        )
 
         c.run()
 
@@ -242,8 +331,9 @@ class RunBoltztrap(FiretaskBase):
         vasprun, outcar = get_vasprun_outcar(".", parse_dos=True, parse_eigen=True)
         bs = vasprun.get_band_structure()
         nelect = outcar.nelect
-        runner = BoltztrapRunner(bs, nelect, scissor=scissor, doping=doping, tmax=tmax,
-                                 tgrid=tgrid, soc=soc)
+        runner = BoltztrapRunner(
+            bs, nelect, scissor=scissor, doping=doping, tmax=tmax, tgrid=tgrid, soc=soc
+        )
 
         runner.run(path_dir=os.getcwd())
 
@@ -261,22 +351,30 @@ class RunNoVasp(FiretaskBase):
 @explicit_serialize
 class RunVaspFake(FiretaskBase):
     """
-     Vasp Emulator
+    Vasp Emulator
 
-     Required params:
-         ref_dir (string): Path to reference vasp run directory with input files in the folder
-            named 'inputs' and output files in the folder named 'outputs'.
+    Required params:
+        ref_dir (string): Path to reference vasp run directory with input files in the folder
+           named 'inputs' and output files in the folder named 'outputs'.
+
+    Optional params:
+        params_to_check (list): optional list of incar parameters to check.
+        check_incar (bool): whether to confirm the INCAR params (default: True)
+        check_kpoints (bool): whether to confirm the KPOINTS params (default: True)
+        check_poscar (bool): whether to confirm the POSCAR params (default: True)
+        check_potcar (bool): whether to confirm the POTCAR params (default: True)
+        clear_inputs (bool): whether to delete VASP input files after running (default: True)
+    """
 
-     Optional params:
-         params_to_check (list): optional list of incar parameters to check.
-         check_incar (bool): whether to confirm the INCAR params (default: True)
-         check_kpoints (bool): whether to confirm the KPOINTS params (default: True)
-         check_poscar (bool): whether to confirm the POSCAR params (default: True)
-         check_potcar (bool): whether to confirm the POTCAR params (default: True)
-         clear_inputs (bool): whether to delete VASP input files after running (default: True)
-     """
     required_params = ["ref_dir"]
-    optional_params = ["params_to_check", "check_incar", "check_kpoints", "check_poscar", "check_potcar", "clear_inputs"]
+    optional_params = [
+        "params_to_check",
+        "check_incar",
+        "check_kpoints",
+        "check_poscar",
+        "check_potcar",
+        "clear_inputs",
+    ]
 
     def run_task(self, fw_spec):
         self._verify_inputs()
@@ -291,43 +389,77 @@ class RunVaspFake(FiretaskBase):
 
         # Check INCAR
         if self.get("check_incar", True):
-            ref_incar = Incar.from_file(os.path.join(self["ref_dir"], "inputs", "INCAR"))
+            ref_incar = Incar.from_file(
+                os.path.join(self["ref_dir"], "inputs", "INCAR")
+            )
             params_to_check = self.get("params_to_check", [])
             defaults = {"ISPIN": 1, "ISMEAR": 1, "SIGMA": 0.2}
             for p in params_to_check:
-                if user_incar.get(p, defaults.get(p)) != ref_incar.get(p, defaults.get(p)):
-                    raise ValueError("INCAR value of {} is inconsistent!".format(p))
+                if user_incar.get(p, defaults.get(p)) != ref_incar.get(
+                    p, defaults.get(p)
+                ):
+                    raise ValueError(f"INCAR value of {p} is inconsistent!")
 
         # Check KPOINTS
         if self.get("check_kpoints", True):
             user_kpoints = Kpoints.from_file(os.path.join(os.getcwd(), "KPOINTS"))
-            ref_kpoints = Kpoints.from_file(os.path.join(self["ref_dir"], "inputs", "KPOINTS"))
-            if user_kpoints.style != ref_kpoints.style or \
-                            user_kpoints.num_kpts != ref_kpoints.num_kpts:
-                raise ValueError("KPOINT files are inconsistent! Paths are:\n{}\n{} with kpoints {} and {}".format(
-                    os.getcwd(), os.path.join(self["ref_dir"], "inputs"), user_kpoints, ref_kpoints))
+            ref_kpoints = Kpoints.from_file(
+                os.path.join(self["ref_dir"], "inputs", "KPOINTS")
+            )
+            if (
+                user_kpoints.style != ref_kpoints.style
+                or user_kpoints.num_kpts != ref_kpoints.num_kpts
+            ):
+                raise ValueError(
+                    "KPOINT files are inconsistent! Paths are:\n{}\n{} with kpoints {} and {}".format(
+                        os.getcwd(),
+                        os.path.join(self["ref_dir"], "inputs"),
+                        user_kpoints,
+                        ref_kpoints,
+                    )
+                )
 
         # Check POSCAR
         if self.get("check_poscar", True):
             user_poscar = Poscar.from_file(os.path.join(os.getcwd(), "POSCAR"))
-            ref_poscar = Poscar.from_file(os.path.join(self["ref_dir"], "inputs", "POSCAR"))
-            if user_poscar.natoms != ref_poscar.natoms or user_poscar.site_symbols != \
-                    ref_poscar.site_symbols:
-                raise ValueError("POSCAR files are inconsistent! Paths are:\n{}\n{}".format(
-                    os.getcwd(), os.path.join(self["ref_dir"], "inputs")))
+            ref_poscar = Poscar.from_file(
+                os.path.join(self["ref_dir"], "inputs", "POSCAR")
+            )
+            if (
+                user_poscar.natoms != ref_poscar.natoms
+                or user_poscar.site_symbols != ref_poscar.site_symbols
+            ):
+                raise ValueError(
+                    "POSCAR files are inconsistent! Paths are:\n{}\n{}".format(
+                        os.getcwd(), os.path.join(self["ref_dir"], "inputs")
+                    )
+                )
 
         # Check POTCAR
         if self.get("check_potcar", True):
             user_potcar = Potcar.from_file(os.path.join(os.getcwd(), "POTCAR"))
-            ref_potcar = Potcar.from_file(os.path.join(self["ref_dir"], "inputs", "POTCAR"))
+            ref_potcar = Potcar.from_file(
+                os.path.join(self["ref_dir"], "inputs", "POTCAR")
+            )
             if user_potcar.symbols != ref_potcar.symbols:
-                raise ValueError("POTCAR files are inconsistent! Paths are:\n{}\n{}".format(
-                    os.getcwd(), os.path.join(self["ref_dir"], "inputs")))
+                raise ValueError(
+                    "POTCAR files are inconsistent! Paths are:\n{}\n{}".format(
+                        os.getcwd(), os.path.join(self["ref_dir"], "inputs")
+                    )
+                )
 
         logger.info("RunVaspFake: verified inputs successfully")
 
     def _clear_inputs(self):
-        for x in ["INCAR", "KPOINTS", "POSCAR", "POTCAR", "CHGCAR", "OUTCAR", "vasprun.xml"]:
+        for x in [
+            "INCAR",
+            "KPOINTS",
+            "POSCAR",
+            "POTCAR",
+            "CHGCAR",
+            "OUTCAR",
+            "vasprun.xml",
+        ]:
             p = os.path.join(os.getcwd(), x)
             if os.path.exists(p):
                 os.remove(p)
