@@ -1,5 +1,3 @@
-# coding: utf-8
-
 from fireworks import Firework
 
 from pymatgen.io.vasp.sets import MPNMRSet
@@ -12,17 +10,19 @@ from atomate.vasp.firetasks.write_inputs import WriteVaspNMRFromPrev, WriteVaspF
 
 
 class NMRFW(Firework):
-    def __init__(self,
-                 structure=None,
-                 mode="cs",
-                 isotopes=None,
-                 name="nmr tensor",
-                 prev_calc_dir=None,
-                 vasp_cmd="vasp",
-                 copy_vasp_outputs=True,
-                 db_file=None,
-                 parents=None,
-                 **kwargs):
+    def __init__(
+        self,
+        structure=None,
+        mode="cs",
+        isotopes=None,
+        name="nmr tensor",
+        prev_calc_dir=None,
+        vasp_cmd="vasp",
+        copy_vasp_outputs=True,
+        db_file=None,
+        parents=None,
+        **kwargs
+    ):
         """
         Firework for NMR tensor calculations
 
@@ -42,25 +42,35 @@ class NMRFW(Firework):
                 FW or list of FWS.
             kwargs: Other kwargs that are passed to Firework.__init__.
         """
-        fw_name = "{}-{}".format(structure.composition.reduced_formula if structure else "unknown", name)
+        fw_name = "{}-{}".format(
+            structure.composition.reduced_formula if structure else "unknown", name
+        )
 
         isotopes = isotopes.split() if isinstance(isotopes, str) else isotopes
         t = []
         if prev_calc_dir:
             t.append(CopyVaspOutputs(calc_dir=prev_calc_dir, contcar_to_poscar=True))
-            t.append(WriteVaspNMRFromPrev(prev_calc_dir=".", mode=mode, isotopes=isotopes))
+            t.append(
+                WriteVaspNMRFromPrev(prev_calc_dir=".", mode=mode, isotopes=isotopes)
+            )
         elif parents and copy_vasp_outputs:
             t.append(CopyVaspOutputs(calc_loc=True, contcar_to_poscar=True))
-            t.append(WriteVaspNMRFromPrev(prev_calc_dir=".", mode=mode, isotopes=isotopes))
+            t.append(
+                WriteVaspNMRFromPrev(prev_calc_dir=".", mode=mode, isotopes=isotopes)
+            )
         elif structure:
             vasp_input_set = MPNMRSet(structure, mode=mode, isotopes=isotopes)
-            t.append(WriteVaspFromIOSet(structure=structure, vasp_input_set=vasp_input_set))
+            t.append(
+                WriteVaspFromIOSet(structure=structure, vasp_input_set=vasp_input_set)
+            )
         else:
             raise ValueError("Must specify structure or previous calculation.")
 
-        t.extend([
-            RunVaspCustodian(vasp_cmd=vasp_cmd, auto_npar=">>auto_npar<<"),
-            PassCalcLocs(name=name),
-            VaspToDb(db_file=db_file, additional_fields={"task_label": name})
-        ])
-        super(NMRFW, self).__init__(t, parents=parents, name=fw_name, **kwargs)
\ No newline at end of file
+        t.extend(
+            [
+                RunVaspCustodian(vasp_cmd=vasp_cmd, auto_npar=">>auto_npar<<"),
+                PassCalcLocs(name=name),
+                VaspToDb(db_file=db_file, additional_fields={"task_label": name}),
+            ]
+        )
+        super().__init__(t, parents=parents, name=fw_name, **kwargs)
