@@ -1,5 +1,3 @@
-# coding: utf-8
-
 import os
 
 from atomate.vasp.fireworks.core import OptimizeFW, StaticFW
@@ -169,7 +167,7 @@ class MagneticOrderingsWF:
             strategies (tuple): different ordering strategies to use, choose
                 from: ferromagnetic, antiferromagnetic,
                 antiferromagnetic_by_motif, ferrimagnetic_by_motif and
-                ferrimagnetic_by_species (here, "motif", 
+                ferrimagnetic_by_species (here, "motif",
                 means to use a different ordering parameter for symmetry
                 inequivalent sites)
             automatic (bool): if True, will automatically choose sensible
@@ -179,7 +177,7 @@ class MagneticOrderingsWF:
             transformation_kwargs (dict): keyword arguments to pass to
                 MagOrderingTransformation, to change automatic cell size
                 limits, etc.
-            static (bool): Run only static calcs (no optimization) of 
+            static (bool): Run only static calcs (no optimization) of
                 different magnetic orderings in a fixed ground state
                 geometry.
 
@@ -303,7 +301,7 @@ class MagneticOrderingsWF:
 
             analyzer = CollinearMagneticStructureAnalyzer(ordered_structure)
 
-            name = " ordering {} {} -".format(idx, analyzer.ordering.value)
+            name = f" ordering {idx} {analyzer.ordering.value} -"
 
             if not scan:
 
@@ -335,10 +333,10 @@ class MagneticOrderingsWF:
                         name=name + " static",
                         prev_calc_loc=True,
                         parents=fws[-1],
-                        vasptodb_kwargs={'parse_chgcar': True, 'parse_aeccar': True}
+                        vasptodb_kwargs={"parse_chgcar": True, "parse_aeccar": True},
                     )
                 )
-                
+
                 if not self.static:
                     # so a failed optimize doesn't crash workflow
                     fws[-1].spec["_allow_fizzled_parents"] = True
@@ -375,14 +373,14 @@ class MagneticOrderingsWF:
         fws.append(fw_analysis)
 
         formula = self.sanitized_structure.composition.reduced_formula
-        wf_name = "{} - magnetic orderings".format(formula)
+        wf_name = f"{formula} - magnetic orderings"
         if scan:
             wf_name += " - SCAN"
         wf = Workflow(fws, name=wf_name)
 
         wf = add_additional_fields_to_taskdocs(wf, {"wf_meta": self.wf_meta})
 
-        tag = "magnetic_orderings group: >>{}<<".format(self.uuid)
+        tag = f"magnetic_orderings group: >>{self.uuid}<<"
         wf = add_tags(wf, [tag, ordered_structure_origins])
 
         return wf
@@ -403,7 +401,7 @@ def get_commensurate_orderings(magnetic_structures, energies):
         energies (list): Energies per atom.
 
     Returns:
-        matched_structures (list): Commensurate supercells for static 
+        matched_structures (list): Commensurate supercells for static
             calculations.
 
     TODO:
@@ -425,7 +423,7 @@ def get_commensurate_orderings(magnetic_structures, energies):
     cmsa = CollinearMagneticStructureAnalyzer(
         es_struct, threshold=0.0, threshold_nonmag=1.0, make_primitive=False
     )
-    es_ordering = cmsa.ordering.value
+    cmsa.ordering.value
     es_struct = cmsa.structure
 
     cmsa = CollinearMagneticStructureAnalyzer(
@@ -484,7 +482,7 @@ def get_commensurate_orderings(magnetic_structures, energies):
         gs_struct, threshold=0.0, make_primitive=False
     )
 
-    enum_index = [cmsa.matches_ordering(s) for s in matched_structures].index(True)
+    [cmsa.matches_ordering(s) for s in matched_structures].index(True)
 
     # Enforce all magmom magnitudes to match the gs
     for s in matched_structures:
