@@ -1,6 +1,3 @@
-# coding: utf-8
-
-
 """
 This module defines the workflow to compute the Raman susceptibility tensor.
 """
@@ -13,14 +10,16 @@ from atomate.utils.utils import get_logger
 from atomate.vasp.fireworks.core import OptimizeFW, DFPTFW, RamanFW
 from atomate.vasp.firetasks.parse_outputs import RamanTensorToDb
 
-__author__ = 'Kiran Mathew'
-__email__ = 'kmathew@lbl.gov'
+__author__ = "Kiran Mathew"
+__email__ = "kmathew@lbl.gov"
 
 logger = get_logger(__name__)
 
 
 # TODO: @kmathew - can symmetry reduce the number of modes? -computron
-def get_wf_raman_spectra(structure, modes=None, step_size=0.005, vasp_cmd="vasp", db_file=None):
+def get_wf_raman_spectra(
+    structure, modes=None, step_size=0.005, vasp_cmd="vasp", db_file=None
+):
     """
     Raman susceptibility tensor workflow:
         Calculation of phonon normal modes followed by the computation of dielectric tensor for
@@ -50,12 +49,23 @@ def get_wf_raman_spectra(structure, modes=None, step_size=0.005, vasp_cmd="vasp"
     fws = []
 
     # Structure optimization
-    fw_opt = OptimizeFW(structure=structure, vasp_input_set=vis,  ediffg=None, vasp_cmd=vasp_cmd,
-                        db_file=db_file)
+    fw_opt = OptimizeFW(
+        structure=structure,
+        vasp_input_set=vis,
+        ediffg=None,
+        vasp_cmd=vasp_cmd,
+        db_file=db_file,
+    )
     fws.append(fw_opt)
 
     # Static run: compute the normal modes and pass
-    fw_leps = DFPTFW(structure=structure, vasp_cmd=vasp_cmd, db_file=db_file, parents=fw_opt, pass_nm_results=True)
+    fw_leps = DFPTFW(
+        structure=structure,
+        vasp_cmd=vasp_cmd,
+        db_file=db_file,
+        parents=fw_opt,
+        pass_nm_results=True,
+    )
 
     fws.append(fw_leps)
 
@@ -63,13 +73,24 @@ def get_wf_raman_spectra(structure, modes=None, step_size=0.005, vasp_cmd="vasp"
     fws_nm_disp = []
     for mode in modes:
         for disp in displacements:
-            fws_nm_disp.append(RamanFW(mode, disp, structure=structure,
-                                       parents=fw_leps, vasp_cmd=vasp_cmd, db_file=db_file))
+            fws_nm_disp.append(
+                RamanFW(
+                    mode,
+                    disp,
+                    structure=structure,
+                    parents=fw_leps,
+                    vasp_cmd=vasp_cmd,
+                    db_file=db_file,
+                )
+            )
     fws.extend(fws_nm_disp)
 
     # Compute the Raman susceptibility tensor
-    fw_analysis = Firework(RamanTensorToDb(db_file=db_file), parents=fws[:],
-                           name="{}-{}".format(structure.composition.reduced_formula, "raman analysis"))
+    fw_analysis = Firework(
+        RamanTensorToDb(db_file=db_file),
+        parents=fws[:],
+        name="{}-{}".format(structure.composition.reduced_formula, "raman analysis"),
+    )
     fws.append(fw_analysis)
 
     wfname = "{}:{}".format(structure.composition.reduced_formula, "raman spectra")
