@@ -1,6 +1,3 @@
-# coding: utf-8
-
-
 """
 This module defines the thermal expansion coefficient workflow.
 """
@@ -16,17 +13,28 @@ from atomate.utils.utils import get_logger
 from atomate.vasp.firetasks.parse_outputs import ThermalExpansionCoeffToDb
 from atomate.vasp.workflows.base.deformations import get_wf_deformations
 
-__author__ = 'Kiran Mathew'
-__email__ = 'kmathew@lbl.gov'
+__author__ = "Kiran Mathew"
+__email__ = "kmathew@lbl.gov"
 
 logger = get_logger(__name__)
 
 
-def get_wf_thermal_expansion(structure, deformations, vasp_input_set=None, vasp_cmd="vasp",
-                             db_file=None, user_kpoints_settings=None, t_step=10, t_min=0,
-                             t_max=1000, mesh=(20, 20, 20), eos="vinet", pressure=0.0,
-                             copy_vasp_outputs=False,
-                             tag=None):
+def get_wf_thermal_expansion(
+    structure,
+    deformations,
+    vasp_input_set=None,
+    vasp_cmd="vasp",
+    db_file=None,
+    user_kpoints_settings=None,
+    t_step=10,
+    t_min=0,
+    t_max=1000,
+    mesh=(20, 20, 20),
+    eos="vinet",
+    pressure=0.0,
+    copy_vasp_outputs=False,
+    tag=None,
+):
     """
     Returns quasi-harmonic thermal expansion workflow.
     Note: phonopy package is required for the final analysis step.
@@ -55,28 +63,51 @@ def get_wf_thermal_expansion(structure, deformations, vasp_input_set=None, vasp_
         Workflow
     """
     try:
-        from phonopy import Phonopy
+        pass
     except ImportError:
-        logger.warning("'phonopy' package NOT installed. Required for the final analysis step.")
+        logger.warning(
+            "'phonopy' package NOT installed. Required for the final analysis step."
+        )
 
     tag = tag or "thermal_expansion group: >>{}<<".format(str(uuid4()))
 
     deformations = [Deformation(defo_mat) for defo_mat in deformations]
 
-    vis_static = vasp_input_set or MPStaticSet(structure, force_gamma=True, lepsilon=True,
-                                               user_kpoints_settings=user_kpoints_settings)
-    wf_alpha = get_wf_deformations(structure, deformations, name="thermal_expansion deformation",
-                                   vasp_cmd=vasp_cmd, db_file=db_file, tag=tag,
-                                   copy_vasp_outputs=copy_vasp_outputs,
-                                   vasp_input_set=vis_static)
+    vis_static = vasp_input_set or MPStaticSet(
+        structure,
+        force_gamma=True,
+        lepsilon=True,
+        user_kpoints_settings=user_kpoints_settings,
+    )
+    wf_alpha = get_wf_deformations(
+        structure,
+        deformations,
+        name="thermal_expansion deformation",
+        vasp_cmd=vasp_cmd,
+        db_file=db_file,
+        tag=tag,
+        copy_vasp_outputs=copy_vasp_outputs,
+        vasp_input_set=vis_static,
+    )
 
-    fw_analysis = Firework(ThermalExpansionCoeffToDb(tag=tag, db_file=db_file, t_step=t_step,
-                                                     t_min=t_min, t_max=t_max, mesh=mesh, eos=eos,
-                                                     pressure=pressure),
-                           name="Thermal expansion")
+    fw_analysis = Firework(
+        ThermalExpansionCoeffToDb(
+            tag=tag,
+            db_file=db_file,
+            t_step=t_step,
+            t_min=t_min,
+            t_max=t_max,
+            mesh=mesh,
+            eos=eos,
+            pressure=pressure,
+        ),
+        name="Thermal expansion",
+    )
 
     wf_alpha.append_wf(Workflow.from_Firework(fw_analysis), wf_alpha.leaf_fw_ids)
 
-    wf_alpha.name = "{}:{}".format(structure.composition.reduced_formula, "thermal expansion")
+    wf_alpha.name = "{}:{}".format(
+        structure.composition.reduced_formula, "thermal expansion"
+    )
 
     return wf_alpha
